@@ -137,16 +137,16 @@ pref("browser.cache.disk.enable",           true);
 pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
-// Size explicitly set by the user. Used when smart_size.enabled == false
+// Size (in KB) explicitly set by the user. Used when smart_size.enabled == false
 pref("browser.cache.disk.capacity",         256000);
-// User-controllable max-size for entries in disk-cache. Regardless of this
-// setting, no entries bigger than 1/8 of disk-cache will be cached
-pref("browser.cache.disk.max_entry_size",    5120);
+// Max-size (in KB) for entries in disk cache. Set to -1 for no limit.
+// (Note: entries bigger than 1/8 of disk-cache are never cached)
+pref("browser.cache.disk.max_entry_size",    51200);  // 50 MB
 pref("browser.cache.memory.enable",         true);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
 //pref("browser.cache.memory.capacity",     -1);
-// User-controllable max-size for entries in mem-cache. Regardless of this
-// setting, no entries bigger than 90% of the mem-cache will be cached
+// Max-size (in KB) for entries in memory cache. Set to -1 for no limit.  
+// (Note: entries bigger than than 90% of the mem-cache are never cached)
 pref("browser.cache.memory.max_entry_size",  5120);
 pref("browser.cache.disk_cache_ssl",        true);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
@@ -678,7 +678,10 @@ pref("javascript.options.methodjit.content", true);
 pref("javascript.options.methodjit.chrome",  true);
 pref("javascript.options.jitprofiling.content", true);
 pref("javascript.options.jitprofiling.chrome",  true);
+pref("javascript.options.pccounts.content", false);
+pref("javascript.options.pccounts.chrome",  false);
 pref("javascript.options.methodjit_always", false);
+pref("javascript.options.typeinference", true);
 // This preference limits the memory usage of javascript.
 // If you want to change these values for your device,
 // please find Bug 417052 comment 17 and Bug 456721
@@ -716,7 +719,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 667 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 670 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -768,9 +771,9 @@ pref("network.http.keep-alive.timeout", 115);
 // cannot allocate that many FDs, and it also always tries to reserve up to 250
 // file descriptors for things other than sockets.   
 // -- windows using lower limit until bug 692260 resolved
-//@line 721 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 724 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.http.max-connections", 256);
-//@line 723 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 726 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // limit the absolute number of http connections that can be established per
 // host.  if a http proxy server is enabled, then the "server" is the proxy
@@ -1073,7 +1076,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 1031 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1034 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1134,7 +1137,6 @@ pref("converter.html2txt.structs",          true); // Output structured phrases
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
 pref("intl.accept_languages",               "chrome://global/locale/intl.properties");
-pref("intl.accept_charsets",                "iso-8859-1,*,utf-8");
 pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.static",     "chrome://global/locale/intl.properties");
@@ -1163,6 +1165,7 @@ pref("font.language.group",                 "chrome://global/locale/intl.propert
 pref("intl.uidirection.ar", "rtl");
 pref("intl.uidirection.he", "rtl");
 pref("intl.uidirection.fa", "rtl");
+pref("intl.uidirection.ur", "rtl");
 
 // use en-US hyphenation by default for content tagged with plain lang="en"
 pref("intl.hyphenation-alias.en", "en-us");
@@ -1182,8 +1185,10 @@ pref("intl.hyphenation-alias.fr-*", "fr");
 pref("intl.hyphenation-alias.gl-*", "gl");
 pref("intl.hyphenation-alias.hr-*", "hr");
 pref("intl.hyphenation-alias.hsb-*", "hsb");
+pref("intl.hyphenation-alias.hu-*", "hu");
 pref("intl.hyphenation-alias.ia-*", "ia");
 pref("intl.hyphenation-alias.is-*", "is");
+pref("intl.hyphenation-alias.it-*", "it");
 pref("intl.hyphenation-alias.kmr-*", "kmr");
 pref("intl.hyphenation-alias.la-*", "la");
 pref("intl.hyphenation-alias.lt-*", "lt");
@@ -1193,6 +1198,7 @@ pref("intl.hyphenation-alias.pt-*", "pt");
 pref("intl.hyphenation-alias.ru-*", "ru");
 pref("intl.hyphenation-alias.sl-*", "sl");
 pref("intl.hyphenation-alias.sv-*", "sv");
+pref("intl.hyphenation-alias.tr-*", "tr");
 pref("intl.hyphenation-alias.uk-*", "uk");
 
 // use reformed (1996) German patterns by default unless specifically tagged as de-1901
@@ -1507,25 +1513,32 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1465 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1471 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
+// How long a plugin process will wait for a response from the parent
+// to a synchronous request before terminating itself. After this
+// point the child assumes the parent is hung.
+// Disabled in release builds for Aurora and up
+pref("dom.ipc.plugins.parentTimeoutSecs", 0);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1476 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1488 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1484 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1496 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
 pref("dom.ipc.plugins.enabled.602plugin.so", false);
-//@line 1491 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1503 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+
+pref("dom.ipc.processCount", 1);
 
 pref("svg.smil.enabled", true);
 
@@ -1562,15 +1575,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1993 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2007 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2426 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2440 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2626 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2640 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2895 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2909 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2899 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2913 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1838,11 +1851,11 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 3170 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3184 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3190 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3204 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3198 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3212 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1891,7 +1904,7 @@ pref("image.mem.discardable", true);
 
 // Prevents images from automatically being decoded on load, instead allowing
 // them to be decoded on demand when they are drawn.
-pref("image.mem.decodeondraw", false);
+pref("image.mem.decodeondraw", true);
 
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
@@ -1920,17 +1933,19 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3279 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3293 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
-//@line 3284 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3298 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 pref("layers.acceleration.disabled", false);
-//@line 3286 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3300 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3304 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
+pref("layers.acceleration.draw-fps", false);
+
+//@line 3320 "/builds/slave/m-beta-lnx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
@@ -1966,5 +1981,20 @@ pref("network.buffer.cache.size",  32768);
 // Desktop Notification
 pref("notification.feature.enabled", false);
 
+// Alert sliding effect
+pref("alerts.slideIncrement", 1);
+pref("alerts.slideIncrementTime", 10);
+pref("alerts.totalOpenTime", 4000);
+pref("alerts.disableSlidingEffect", false);
+
+// DOM full-screen API.
+pref("full-screen-api.enabled", false);
+pref("full-screen-api.allow-trusted-requests-only", true);
+pref("full-screen-api.key-input-restricted", true);
+
+// Time limit, in milliseconds, for nsEventStateManager::IsHandlingUserInput().
+// Used to detect long running handlers of user-generated events.
+pref("dom.event.handling-user-input-time-limit", 1000);
+ 
 //3D Transforms
-pref("layout.3d-transforms.enabled, false);
+pref("layout.3d-transforms.enabled", false);
